aboutsummaryrefslogtreecommitdiff
path: root/gdb/solib-target.c
diff options
context:
space:
mode:
Diffstat (limited to 'gdb/solib-target.c')
-rw-r--r--gdb/solib-target.c10
1 files changed, 5 insertions, 5 deletions
diff --git a/gdb/solib-target.c b/gdb/solib-target.c
index 2e1c74f..e93fe8e 100644
--- a/gdb/solib-target.c
+++ b/gdb/solib-target.c
@@ -227,10 +227,10 @@ solib_target_parse_libraries (const char *library)
}
#endif
-static intrusive_list<so_list>
+static intrusive_list<shobj>
solib_target_current_sos (void)
{
- intrusive_list<so_list> sos;
+ intrusive_list<shobj> sos;
/* Fetch the list of shared libraries. */
gdb::optional<gdb::char_vector> library_document
@@ -243,10 +243,10 @@ solib_target_current_sos (void)
std::vector<lm_info_target_up> library_list
= solib_target_parse_libraries (library_document->data ());
/* Build a struct so_list for each entry on the list. */
for (lm_info_target_up &info : library_list)
{
- so_list *new_solib = new so_list;
+ shobj *new_solib = new shobj;
/* We don't need a copy of the name in INFO anymore. */
new_solib->so_name = std::move (info->name);
@@ -267,7 +267,7 @@ solib_target_solib_create_inferior_hook (int from_tty)
}
static void
-solib_target_relocate_section_addresses (so_list &so, target_section *sec)
+solib_target_relocate_section_addresses (shobj &so, target_section *sec)
{
CORE_ADDR offset;
auto *li = gdb::checked_static_cast<lm_info_target *> (so.lm_info.get ());
@@ -243,10 +243,10 @@ solib_target_current_sos (void)
std::vector<lm_info_target_up> library_list
= solib_target_parse_libraries (library_document->data ());
- /* Build a struct so_list for each entry on the list. */
+ /* Build a struct shobj for each entry on the list. */
for (lm_info_target_up &info : library_list)
{